@@ -32,10 +32,16 @@ def process_lane(*args):
     with _setup_logging(args):
         return apply(lane.process_lane, *args)
 
+@require(lane)
+def trim_lane(*args):
+    with _setup_logging(args):
+        return apply(lane.trim_lane, *args)
+
 @require(lane)
 def process_alignment(*args):
     with _setup_logging(args):
         return apply(lane.process_alignment, *args)
+process_alignment.metadata = {"resources": ["novoalign"]}
 
 @require(sample)
 def merge_sample(*args):
@@ -51,7 +57,7 @@ def recalibrate_sample(*args):
 def prep_recal(*args):
     with _setup_logging(args):
         return apply(recalibrate.prep_recal, *args)
-prep_recal.metadata = {"queue_type": "multicore"}
+prep_recal.metadata = {"resources": ["gatk"]}
 
 @require(recalibrate)
 def write_recal_bam(*args):
