@@ -2,12 +2,16 @@
 """
 from bcbio import utils
 from bcbio.pipeline import sample, lane, shared, variation
-from bcbio.variation import realign, genotype
+from bcbio.variation import realign, genotype, ensemble, recalibrate, multi
 
 @utils.map_wrap
 def process_lane(*args):
     return lane.process_lane(*args)
 
+@utils.map_wrap
+def trim_lane(*args):
+    return lane.trim_lane(*args)
+
 @utils.map_wrap
 def process_alignment(*args):
     return lane.process_alignment(*args)
@@ -17,13 +21,21 @@ def merge_sample(*args):
     return sample.merge_sample(*args)
 
 @utils.map_wrap
-def recalibrate_sample(*args):
-    return sample.recalibrate_sample(*args)
+def prep_recal(*args):
+    return recalibrate.prep_recal(*args)
+
+@utils.map_wrap
+def write_recal_bam(*args):
+    return recalibrate.write_recal_bam(*args)
 
 @utils.map_wrap
 def realign_sample(*args):
     return realign.realign_sample(*args)
 
+@utils.map_wrap
+def split_variants_by_sample(*args):
+    return multi.split_variants_by_sample(*args)
+
 @utils.map_wrap
 def postprocess_variants(*args):
     return sample.postprocess_variants(*args)
@@ -51,3 +63,7 @@ def combine_variant_files(*args):
 @utils.map_wrap
 def detect_sv(*args):
     return variation.detect_sv(*args)
+
+@utils.map_wrap
+def combine_calls(*args):
+    return ensemble.combine_calls(*args)
