@@ -9,11 +9,13 @@ import collections
 import pysam
 
 from bcbio import broad
-from bcbio.utils import file_exists, safe_makedir
+from bcbio.bam import cram
 from bcbio.distributed.transaction import file_transaction
+from bcbio.pipeline import alignment
+from bcbio.utils import file_exists, safe_makedir
 
 def get_fastq_files(directory, work_dir, item, fc_name, bc_name=None,
-                    config=None):
+                    config=None, dirs=None):
     """Retrieve fastq files for the given lane, ready to process.
     """
     if item.has_key("files") and bc_name is None:
@@ -41,7 +43,7 @@ def get_fastq_files(directory, work_dir, item, fc_name, bc_name=None,
             ready_files.append(os.path.splitext(fname)[0])
         elif fname.endswith(".bam"):
             if _pipeline_needs_fastq(config, item):
-                ready_files = convert_bam_to_fastq(fname, work_dir, config)
+                ready_files = convert_bam_to_fastq(fname, work_dir, item, dirs, config)
             else:
                 ready_files = [fname]
         else:
@@ -51,16 +53,27 @@ def get_fastq_files(directory, work_dir, item, fc_name, bc_name=None,
     return ready_files[0], (ready_files[1] if len(ready_files) > 1 else None)
 
 def _pipeline_needs_fastq(config, item):
-    do_align = (config["algorithm"].get("aligner", None) and
-                item["algorithm"].get("aligner", True))
+    """Determine if the pipeline can proceed with a BAM file, or needs fastq conversion.
+    """
+    aligner = config["algorithm"].get("aligner")
     has_multiplex = item.get("multiplex") is not None
-    do_split = item["algorithm"].get("align_split_size") is not None
-    return has_multiplex or (do_align and not do_split)
+    do_split = config["algorithm"].get("align_split_size") is not None
+    support_bam = aligner in alignment.metadata.get("support_bam", [])
+    return (has_multiplex or
+            (aligner and not do_split and not support_bam))
 
-def convert_bam_to_fastq(in_file, work_dir, config):
+def convert_bam_to_fastq(in_file, work_dir, item, dirs, config):
     """Convert BAM input file into FASTQ files.
     """
     out_dir = safe_makedir(os.path.join(work_dir, "fastq_convert"))
+
+    qual_bin_method = config["algorithm"].get("quality_bin")
+    if (qual_bin_method == "prealignment" or
+         (isinstance(qual_bin_method, list) and "prealignment" in qual_bin_method)):
+        _, sam_ref = alignment.get_genome_ref(item["genome_build"], None, dirs["galaxy"])
+        out_bindir = safe_makedir(os.path.join(out_dir, "qualbin"))
+        in_file = cram.illumina_qual_bin(in_file, sam_ref, out_bindir, config)
+
     out_files = [os.path.join(out_dir, "{0}_{1}.fastq".format(
                  os.path.splitext(os.path.basename(in_file))[0], x))
                  for x in ["1", "2"]]
