@@ -13,8 +13,7 @@ from bcbio.pipeline.lane import _update_config_w_custom
 from bcbio.log import logger
 from bcbio.pipeline.merge import (combine_fastq_files, merge_bam_files)
 from bcbio.pipeline.qcsummary import generate_align_summary
-from bcbio.pipeline.variation import (recalibrate_quality, finalize_genotyper,
-                                      variation_effects)
+from bcbio.pipeline.variation import (finalize_genotyper, variation_effects)
 from bcbio.rnaseq.cufflinks import assemble_transcripts
 from bcbio.pipeline.shared import ref_genome_info
 
@@ -24,28 +23,19 @@ def merge_sample(data):
     logger.info("Combining fastq and BAM files %s" % str(data["name"]))
     config = _update_config_w_custom(data["config"], data["info"])
     genome_build, sam_ref = ref_genome_info(data["info"], config, data["dirs"])
-    fastq1, fastq2 = combine_fastq_files(data["fastq_files"], data["dirs"]["work"],
-                                         config)
+    if config["algorithm"].get("upload_fastq", False):
+        fastq1, fastq2 = combine_fastq_files(data["fastq_files"], data["dirs"]["work"],
+                                             config)
+    else:
+        fastq1, fastq2 = None, None
     sort_bam = merge_bam_files(data["bam_files"], data["dirs"]["work"], config)
-    return [[{"name": data["name"],
+    return [[{"name": data["name"], "metadata": data["info"].get("metadata", {}),
+              "info": data["info"],
               "genome_build": genome_build, "sam_ref": sam_ref,
               "work_bam": sort_bam, "fastq1": fastq1, "fastq2": fastq2,
               "dirs": data["dirs"], "config": config,
               "config_file": data["config_file"]}]]
 
-def recalibrate_sample(data):
-    """Recalibrate quality values from aligned sample BAM file.
-    """
-    logger.info("Recalibrating %s with GATK" % str(data["name"]))
-    if data["config"]["algorithm"]["recalibrate"]:
-        recal_bam = recalibrate_quality(data["work_bam"], data["fastq1"],
-                                        data["fastq2"], data["sam_ref"],
-                                        data["dirs"], data["config"])
-        save_diskspace(data["work_bam"], "Recalibrated to %s" % recal_bam,
-                       data["config"])
-        data["work_bam"] = recal_bam
-    return [[data]]
-
 # ## General processing
 
 def postprocess_variants(data):
@@ -56,13 +46,10 @@ def postprocess_variants(data):
         data["vrn_file"] = finalize_genotyper(data["vrn_file"], data["work_bam"],
                                               data["sam_ref"], data["config"])
         logger.info("Calculating variation effects for %s" % str(data["name"]))
-        ann_vrn_file, effects_file = variation_effects(data["vrn_file"],
-                                                       data["sam_ref"],
-                                                       data["genome_build"],
-                                                       data["config"])
+        ann_vrn_file = variation_effects(data["vrn_file"], data["sam_ref"],
+                                         data["genome_build"], data["config"])
         if ann_vrn_file:
             data["vrn_file"] = ann_vrn_file
-            data["effects_file"] = effects_file
     return [[data]]
 
 def process_sample(data):
@@ -73,9 +60,9 @@ def process_sample(data):
                                                data["config"])
     if data["sam_ref"] is not None:
         logger.info("Generating summary files: %s" % str(data["name"]))
-        generate_align_summary(data["work_bam"], data["fastq2"] is not None,
-                               data["sam_ref"], data["name"],
-                               data["config"], data["dirs"])
+        data["summary"] = generate_align_summary(data["work_bam"], data["fastq2"] is not None,
+                                                 data["sam_ref"], data["name"],
+                                                 data["config"], data["dirs"])
     return [[data]]
 
 def generate_bigwig(data):
@@ -86,8 +73,7 @@ def generate_bigwig(data):
     wig_file = "%s.bigwig" % os.path.splitext(bam_file)[0]
     if not file_exists(wig_file):
         with file_transaction(wig_file) as tx_file:
-            cl = [data["config"]["analysis"]["towig_script"], bam_file,
+            cl = ["bam_to_wiggle.py", bam_file,
                   data["config_file"], "--outfile=%s" % tx_file]
             subprocess.check_call(cl)
     return [[data]]
-
