@@ -30,13 +30,15 @@ import os
 import sys
 import subprocess
 
+from bcbio import workflow
 from bcbio.pipeline.run_info import get_run_info
 from bcbio.distributed import manage as messaging
 from bcbio.pipeline.config_utils import load_config
 from bcbio.pipeline.main import run_main, parse_cl_args
 
 def main(config_file, fc_dir=None, run_info_yaml=None, numcores=None,
-         paralleltype=None, queue=None, scheduler=None, upgrade=None):
+         paralleltype=None, queue=None, scheduler=None, upgrade=None,
+         profile=None, workflow=None, inputs=None):
     work_dir = os.getcwd()
     config = load_config(config_file)
     if config.get("log_dir", None) is None:
@@ -45,7 +47,7 @@ def main(config_file, fc_dir=None, run_info_yaml=None, numcores=None,
                                                  numcores, paralleltype)
     parallel = {"type": paralleltype, "cores": numcores,
                 "scheduler": scheduler, "queue": queue,
-                "module": "bcbio.distributed"}
+                "profile": profile, "module": "bcbio.distributed"}
     if parallel["type"] in ["local", "messaging-main"]:
         if numcores is None:
             config["algorithm"]["num_cores"] = numcores
@@ -87,7 +89,7 @@ def _get_cores_and_type(config, fc_dir, run_info_yaml,
         paralleltype = "local"
 
     if numcores is None:
-        if config["distributed"].get("num_workers", "") == "all":
+        if config.get("distributed", {}).get("num_workers", "") == "all":
             cp = config["distributed"]["cluster_platform"]
             cluster = __import__("bcbio.distributed.{0}".format(cp), fromlist=[cp])
             numcores = cluster.available_nodes(config["distributed"]["platform_args"]) - 1
@@ -111,17 +113,24 @@ def _upgrade_bcbio(method):
     """Perform upgrade of bcbio to latest release, or from GitHub development version.
     """
     url = "https://raw.github.com/chapmanb/bcbio-nextgen/master/requirements.txt"
+    git_repo = "git://github.com/chapmanb/bcbio-nextgen.git"
     pip_bin = os.path.join(os.path.dirname(sys.executable), "pip")
     if method in ["stable", "system"]:
         sudo_cmd = [] if method == "stable" else ["sudo"]
         subprocess.check_call(sudo_cmd + [pip_bin, "install", "--upgrade", "distribute"])
         subprocess.check_call(sudo_cmd + [pip_bin, "install", "-r", url])
     else:
-        raise NotImplementedError("Development upgrade")
+        subprocess.check_call([pip_bin, "install", "--upgrade",
+                               "git+%s#egg=bcbio-nextgen" % git_repo])
 
 if __name__ == "__main__":
     config_file, kwargs = parse_cl_args(sys.argv[1:])
+    kwargs["config_file"] = config_file
     if kwargs["upgrade"] and config_file is None:
         _upgrade_bcbio(kwargs["upgrade"])
     else:
-        main(config_file, **kwargs)
+        if kwargs["workflow"]:
+            workdir, new_kwargs = workflow.setup(kwargs["workflow"], kwargs["inputs"])
+            os.chdir(workdir)
+            kwargs.update(new_kwargs)
+        main(**kwargs)
